Release History
===============

0.1.1
+++++

Fix:
- Add Manifest.in to include version.py.

0.1.0
+++++

First release of Core.

This release includes:
- Loading config files
- Reading secrets from vault
- Reading environment variables
